==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QOpenGLContext_shell.h <==
#ifndef QOPENGLCONTEXT_SHELL_H
#define QOPENGLCONTEXT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qopenglcontext.h>
#include <QtJambi/QtJambiAPI>
#include <QSet>
#include <QtCore/QList>
#include <QtCore/QSet>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qopenglextrafunctions.h>
#include <QtGui/qopenglfunctions.h>
#include <QtGui/qopenglversionfunctions.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>


class QOpenGLContext_shell : public QOpenGLContext, public QtJambiShellInterface
{
public:
    QOpenGLContext_shell(QObject* parent0 = nullptr);
    ~QOpenGLContext_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLContext_access : public QOpenGLContext
{
};

#endif // QOPENGLCONTEXT_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QOpenGLContext_shell.h <==
#ifndef QOPENGLCONTEXT_SHELL_H
#define QOPENGLCONTEXT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qopenglcontext.h>
#include <QtJambi/QtJambiAPI>
#include <QSet>
#include <QtCore/QList>
#include <QtCore/QSet>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qopenglextrafunctions.h>
#include <QtGui/qopenglfunctions.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>


class QOpenGLContext_shell : public QOpenGLContext, public QtJambiShellInterface
{
public:
    QOpenGLContext_shell(QObject* parent0 = nullptr);
    ~QOpenGLContext_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QOpenGLContext_mshell;
    friend class QOpenGLContext_oshell;
};


class QOpenGLContext_mshell : public QOpenGLContext_shell
{
public:
    using QOpenGLContext_shell::QOpenGLContext_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QOpenGLContext_oshell : public QOpenGLContext_mshell
{
public:
    using QOpenGLContext_mshell::QOpenGLContext_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLContext_access : public QOpenGLContext
{
    jobject __qt_nativeInterface_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jclass name0) const;
};

#endif // QOPENGLCONTEXT_SHELL_H
